@@ -20,6 +20,7 @@
     { "gtk_icon_file_selection_get_path_label", _wrap_gtk_icon_file_selection_get_path_label, 1 },
     { "gtk_icon_file_selection_get_dir_tree", _wrap_gtk_icon_file_selection_get_dir_tree, 1 },
     { "gtk_icon_file_selection_get_file_list", _wrap_gtk_icon_file_selection_get_file_list, 1 },
+    { "gtk_icon_file_selection_get_history_combo", _wrap_gtk_icon_file_selection_get_history_combo, 1 },
     { "gtk_icon_file_selection_get_file_entry", _wrap_gtk_icon_file_selection_get_file_entry, 1 },
     { "gtk_icon_file_selection_get_filter_entry", _wrap_gtk_icon_file_selection_get_filter_entry, 1 },
     { "gtk_icon_file_selection_get_ok_button", _wrap_gtk_icon_file_selection_get_ok_button, 1 },
@@ -55,6 +56,8 @@
     { "gtk_sheet_set_hadjustment", _wrap_gtk_sheet_set_hadjustment, 1 },
     { "gtk_sheet_set_vadjustment", _wrap_gtk_sheet_set_vadjustment, 1 },
     { "gtk_sheet_change_entry", _wrap_gtk_sheet_change_entry, 1 },
+    { "gtk_sheet_get_entry", _wrap_gtk_sheet_get_entry, 1 },
+    { "gtk_sheet_get_entry_widget", _wrap_gtk_sheet_get_entry_widget, 1 },
     { "gtk_sheet_get_state", _wrap_gtk_sheet_get_state, 1 },
     { "gtk_sheet_get_columns_count", _wrap_gtk_sheet_get_columns_count, 1 },
     { "gtk_sheet_get_rows_count", _wrap_gtk_sheet_get_rows_count, 1 },
@@ -62,6 +65,10 @@
     { "gtk_sheet_set_title", _wrap_gtk_sheet_set_title, 1 },
     { "gtk_sheet_freeze", _wrap_gtk_sheet_freeze, 1 },
     { "gtk_sheet_thaw", _wrap_gtk_sheet_thaw, 1 },
+    { "gtk_sheet_set_background", _wrap_gtk_sheet_set_background, 1 },
+    { "gtk_sheet_set_grid", _wrap_gtk_sheet_set_grid, 1 },
+    { "gtk_sheet_show_grid", _wrap_gtk_sheet_show_grid, 1 },
+    { "gtk_sheet_grid_visible", _wrap_gtk_sheet_grid_visible, 1 },
     { "gtk_sheet_set_column_title", _wrap_gtk_sheet_set_column_title, 1 },
     { "gtk_sheet_set_row_title", _wrap_gtk_sheet_set_row_title, 1 },
     { "gtk_sheet_row_button_add_label", _wrap_gtk_sheet_row_button_add_label, 1 },
@@ -88,6 +95,8 @@
     { "gtk_sheet_select_row", _wrap_gtk_sheet_select_row, 1 },
     { "gtk_sheet_select_column", _wrap_gtk_sheet_select_column, 1 },
     { "gtk_sheet_unclip_range", _wrap_gtk_sheet_unclip_range, 1 },
+    { "gtk_sheet_get_vadjustment", _wrap_gtk_sheet_get_vadjustment, 1 },
+    { "gtk_sheet_get_hadjustment", _wrap_gtk_sheet_get_hadjustment, 1 },
     { "gtk_sheet_unselect_range", _wrap_gtk_sheet_unselect_range, 1 },
     { "gtk_sheet_set_active_cell", _wrap_gtk_sheet_set_active_cell, 1 },
     { "gtk_sheet_set_cell", _wrap_gtk_sheet_set_cell, 1 },
@@ -108,8 +117,11 @@
     { "gtk_sheet_move_child", _wrap_gtk_sheet_move_child, 1 },
     { "gtk_sheet_button_attach", _wrap_gtk_sheet_button_attach, 1 },
     { "gtk_plot_data_paint", _wrap_gtk_plot_data_paint, 1 },
+    { "gtk_plot_data_update", _wrap_gtk_plot_data_update, 1 },
     { "gtk_plot_data_draw_points", _wrap_gtk_plot_data_draw_points, 1 },
     { "gtk_plot_data_draw_symbol", _wrap_gtk_plot_data_draw_symbol, 1 },
+    { "gtk_plot_data_set_a_scale", _wrap_gtk_plot_data_set_a_scale, 1 },
+    { "gtk_plot_data_get_a_scale", _wrap_gtk_plot_data_get_a_scale, 1 },
     { "gtk_plot_data_show_labels", _wrap_gtk_plot_data_show_labels, 1 },
     { "gtk_plot_data_labels_set_attributes", _wrap_gtk_plot_data_labels_set_attributes, 1 },
     { "gtk_plot_data_get_numpoints", _wrap_gtk_plot_data_get_numpoints, 1 },
@@ -137,8 +149,15 @@
     { "gtk_plot_data_get_gradient_mask", _wrap_gtk_plot_data_get_gradient_mask, 1 },
     { "gtk_plot_data_gradient_set_visible", _wrap_gtk_plot_data_gradient_set_visible, 1 },
     { "gtk_plot_data_gradient_visible", _wrap_gtk_plot_data_gradient_visible, 1 },
+    { "gtk_plot_data_draw_gradient", _wrap_gtk_plot_data_draw_gradient, 1 },
+    { "gtk_plot_data_gradient_autoscale_a", _wrap_gtk_plot_data_gradient_autoscale_a, 1 },
+    { "gtk_plot_data_gradient_autoscale_da", _wrap_gtk_plot_data_gradient_autoscale_da, 1 },
+    { "gtk_plot_data_gradient_autoscale_z", _wrap_gtk_plot_data_gradient_autoscale_z, 1 },
     { "gtk_plot_data_set_gradient_colors", _wrap_gtk_plot_data_set_gradient_colors, 1 },
     { "gtk_plot_data_set_gradient", _wrap_gtk_plot_data_set_gradient, 1 },
+    { "gtk_plot_data_remove_markers", _wrap_gtk_plot_data_remove_markers, 1 },
+    { "gtk_plot_data_show_markers", _wrap_gtk_plot_data_show_markers, 1 },
+    { "gtk_plot_data_markers_visible", _wrap_gtk_plot_data_markers_visible, 1 },
     { "gtk_plot_bar_set_width", _wrap_gtk_plot_bar_set_width, 1 },
     { "gtk_plot_bar_get_width", _wrap_gtk_plot_bar_get_width, 1 },
     { "gtk_plot_flux_set_arrow", _wrap_gtk_plot_flux_set_arrow, 1 },
@@ -152,12 +171,16 @@
     { "gtk_plot_surface_get_mesh_visible", _wrap_gtk_plot_surface_get_mesh_visible, 1 },
     { "gtk_plot_surface_set_light", _wrap_gtk_plot_surface_set_light, 1 },
     { "gtk_plot_surface_set_ambient", _wrap_gtk_plot_surface_set_ambient, 1 },
+    { "gtk_plot_surface_use_height_gradient", _wrap_gtk_plot_surface_use_height_gradient, 1 },
+    { "gtk_plot_surface_set_transparent", _wrap_gtk_plot_surface_set_transparent, 1 },
     { "gtk_plot_surface_get_nx", _wrap_gtk_plot_surface_get_nx, 1 },
     { "gtk_plot_surface_get_ny", _wrap_gtk_plot_surface_get_ny, 1 },
     { "gtk_plot_surface_set_xstep", _wrap_gtk_plot_surface_set_xstep, 1 },
     { "gtk_plot_surface_set_ystep", _wrap_gtk_plot_surface_set_ystep, 1 },
     { "gtk_plot_surface_get_xstep", _wrap_gtk_plot_surface_get_xstep, 1 },
     { "gtk_plot_surface_get_ystep", _wrap_gtk_plot_surface_get_ystep, 1 },
+    { "gtk_plot_surface_build_mesh", _wrap_gtk_plot_surface_build_mesh, 1 },
+    { "gtk_plot_surface_recalc_nodes", _wrap_gtk_plot_surface_recalc_nodes, 1 },
     { "gtk_plot_csurface_set_lines_visible", _wrap_gtk_plot_csurface_set_lines_visible, 1 },
     { "gtk_plot_csurface_get_lines_visible", _wrap_gtk_plot_csurface_get_lines_visible, 1 },
     { "gtk_plot_csurface_set_lines_only", _wrap_gtk_plot_csurface_set_lines_only, 1 },
@@ -207,6 +230,8 @@
     { "gtk_plot_axis_title_set_attributes", _wrap_gtk_plot_axis_title_set_attributes, 1 },
     { "gtk_plot_axis_set_labels_attributes", _wrap_gtk_plot_axis_set_labels_attributes, 1 },
     { "gtk_plot_axis_set_labels_numbers", _wrap_gtk_plot_axis_set_labels_numbers, 1 },
+    { "gtk_plot_axis_set_labels_offset", _wrap_gtk_plot_axis_set_labels_offset, 1 },
+    { "gtk_plot_axis_get_labels_offset", _wrap_gtk_plot_axis_get_labels_offset, 1 },
     { "gtk_plot_axis_use_custom_tick_labels", _wrap_gtk_plot_axis_use_custom_tick_labels, 1 },
     { "gtk_plot_axis_set_labels_suffix", _wrap_gtk_plot_axis_set_labels_suffix, 1 },
     { "gtk_plot_axis_set_labels_prefix", _wrap_gtk_plot_axis_set_labels_prefix, 1 },
@@ -275,6 +300,8 @@
     { "gtk_plot_canvas_new", _wrap_gtk_plot_canvas_new, 1 },
     { "gtk_plot_canvas_paint", _wrap_gtk_plot_canvas_paint, 1 },
     { "gtk_plot_canvas_refresh", _wrap_gtk_plot_canvas_refresh, 1 },
+    { "gtk_plot_canvas_freeze", _wrap_gtk_plot_canvas_freeze, 1 },
+    { "gtk_plot_canvas_thaw", _wrap_gtk_plot_canvas_thaw, 1 },
     { "gtk_plot_canvas_grid_set_visible", _wrap_gtk_plot_canvas_grid_set_visible, 1 },
     { "gtk_plot_canvas_grid_set_step", _wrap_gtk_plot_canvas_grid_set_step, 1 },
     { "gtk_plot_canvas_grid_set_attributes", _wrap_gtk_plot_canvas_grid_set_attributes, 1 },
@@ -282,6 +309,8 @@
     { "gtk_plot_canvas_set_active_plot", _wrap_gtk_plot_canvas_set_active_plot, 1 },
     { "gtk_plot_canvas_cancel_action", _wrap_gtk_plot_canvas_cancel_action, 1 },
     { "gtk_plot_canvas_unselect", _wrap_gtk_plot_canvas_unselect, 1 },
+    { "gtk_plot_canvas_get_active_plot", _wrap_gtk_plot_canvas_get_active_plot, 1 },
+    { "gtk_plot_canvas_get_active_data", _wrap_gtk_plot_canvas_get_active_data, 1 },
     { "gtk_plot_canvas_set_size", _wrap_gtk_plot_canvas_set_size, 1 },
     { "gtk_plot_canvas_set_magnification", _wrap_gtk_plot_canvas_set_magnification, 1 },
     { "gtk_plot_canvas_set_background", _wrap_gtk_plot_canvas_set_background, 1 },
